==> openjdk-src-11.0.1.u13-2-armv7h.pkg.tar.xz: jdk.localedata/sun/util/resources/cldr/ext/LocaleNames_fa_AF.java <==
/*
 * Copyright (c) 2012, 2018, Oracle and/or its affiliates. All rights reserved.
 * DO NOT ALTER OR REMOVE COPYRIGHT NOTICES OR THIS FILE HEADER.
 *
 * This code is free software; you can redistribute it and/or modify it
 * under the terms of the GNU General Public License version 2 only, as
 * published by the Free Software Foundation.  Oracle designates this
 * particular file as subject to the "Classpath" exception as provided
 * by Oracle in the LICENSE file that accompanied this code.
 *
 * This code is distributed in the hope that it will be useful, but WITHOUT
 * ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
 * FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License
 * version 2 for more details (a copy is included in the LICENSE file that
 * accompanied this code).
 *
 * You should have received a copy of the GNU General Public License version
 * 2 along with this work; if not, write to the Free Software Foundation,
 * Inc., 51 Franklin St, Fifth Floor, Boston, MA 02110-1301 USA.
 *
 * Please contact Oracle, 500 Oracle Parkway, Redwood Shores, CA 94065 USA
 * or visit www.oracle.com if you need additional information or have any
 * questions.
 */

/*
 * COPYRIGHT AND PERMISSION NOTICE
 *
 * Copyright (C) 1991-2016 Unicode, Inc. All rights reserved.
 * Distributed under the Terms of Use in 
 * http://www.unicode.org/copyright.html.
 *
 * Permission is hereby granted, free of charge, to any person obtaining
 * a copy of the Unicode data files and any associated documentation
 * (the "Data Files") or Unicode software and any associated documentation
 * (the "Software") to deal in the Data Files or Software
 * without restriction, including without limitation the rights to use,
 * copy, modify, merge, publish, distribute, and/or sell copies of
 * the Data Files or Software, and to permit persons to whom the Data Files
 * or Software are furnished to do so, provided that
 * (a) this copyright and permission notice appear with all copies 
 * of the Data Files or Software,
 * (b) this copyright and permission notice appear in associated 
 * documentation, and
 * (c) there is clear notice in each modified Data File or in the Software
 * as well as in the documentation associated with the Data File(s) or
 * Software that the data or software has been modified.
 *
 * THE DATA FILES AND SOFTWARE ARE PROVIDED "AS IS", WITHOUT WARRANTY OF
 * ANY KIND, EXPRESS OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE
 * WARRANTIES OF MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND
 * NONINFRINGEMENT OF THIRD PARTY RIGHTS.
 * IN NO EVENT SHALL THE COPYRIGHT HOLDER OR HOLDERS INCLUDED IN THIS
 * NOTICE BE LIABLE FOR ANY CLAIM, OR ANY SPECIAL INDIRECT OR CONSEQUENTIAL
 * DAMAGES, OR ANY DAMAGES WHATSOEVER RESULTING FROM LOSS OF USE,
 * DATA OR PROFITS, WHETHER IN AN ACTION OF CONTRACT, NEGLIGENCE OR OTHER
 * TORTIOUS ACTION, ARISING OUT OF OR IN CONNECTION WITH THE USE OR
 * PERFORMANCE OF THE DATA FILES OR SOFTWARE.
 *
 * Except as contained in this notice, the name of a copyright holder
 * shall not be used in advertising or otherwise to promote the sale,
 * use or other dealings in these Data Files or Software without prior
 * written authorization of the copyright holder.
 */

package sun.util.resources.cldr.ext;

import sun.util.resources.OpenListResourceBundle;

public class LocaleNames_fa_AF extends OpenListResourceBundle {
    @Override
    protected final Object[][] getContents() {
        final String metaValue_mn = "\u0645\u063a\u0644\u06cc";
        final Object[][] data = new Object[][] {
            { "PT", "\u067e\u0631\u062a\u06af\u0627\u0644" },
            { "pt", "\u067e\u0631\u062a\u06af\u0627\u0644\u06cc" },
            { "HN", "\u0647\u0627\u0646\u062f\u0648\u0631\u0627\u0633" },
            { "PY", "\u067e\u0627\u0631\u0627\u06af\u0648\u0627\u06cc" },
            { "HR", "\u06a9\u0631\u0648\u0634\u06cc\u0627" },
            { "hr", "\u06a9\u0631\u0648\u0634\u06cc\u0627\u06cc\u06cc" },
            { "HT", "\u0647\u0627\u06cc\u062a\u06cc" },
            { "ID", "\u0627\u0646\u062f\u0648\u0646\u06cc\u0632\u06cc\u0627" },
            { "id", "\u0627\u0646\u062f\u0648\u0646\u06cc\u0632\u06cc\u0627\u06cc\u06cc" },
            { "IE", "\u0622\u06cc\u0631\u0644\u0646\u062f" },
            { "ab", "\u0627\u0641\u0631\u06cc\u06a9\u0627\u0646\u0633" },
            { "AD", "\u0627\u0646\u062f\u0648\u0631\u0627" },
            { "AG", "\u0627\u0646\u062a\u06cc\u06af\u0648\u0627 \u0648 \u0628\u0627\u0631\u0628\u0648\u062f\u0627" },
            { "IS", "\u0622\u06cc\u0633\u0644\u0646\u062f" },
            { "is", "\u0622\u06cc\u0633\u0644\u0646\u062f\u06cc" },
            { "AL", "\u0627\u0644\u0628\u0627\u0646\u06cc\u0627" },
            { "it", "\u0627\u06cc\u062a\u0627\u0644\u0648\u06cc" },
            { "AO", "\u0627\u0646\u06af\u0648\u0644\u0627" },
            { "AQ", "\u0627\u0646\u062a\u0631\u06a9\u062a\u06cc\u06a9\u0627" },
            { "AR", "\u0627\u0631\u062c\u0646\u062a\u0627\u06cc\u0646" },
            { "as", "\u0627\u0633\u0627\u0645\u06cc" },
            { "AU", "\u0622\u0633\u062a\u0631\u0627\u0644\u06cc\u0627" },
            { "ja", "\u062c\u0627\u067e\u0627\u0646\u06cc" },
            { "az", "\u0622\u0630\u0631\u0628\u0627\u06cc\u062c\u0627\u0646\u06cc" },
            { "RO", "\u0631\u0648\u0645\u0627\u0646\u06cc\u0627" },
            { "ZW", "\u0632\u06cc\u0645\u0628\u0627\u0628\u0648\u06cc" },
            { "BA", "\u0628\u0648\u0633\u0646\u06cc\u0627 \u0648 \u0647\u0631\u0632\u0647\u200c\u06af\u0648\u06cc\u0646\u0627" },
            { "ba", "\u0628\u0627\u0634\u0642\u06cc\u0631\u06cc" },
            { "BD", "\u0628\u0646\u06af\u0644\u0647\u200c\u062f\u06cc\u0634" },
            { "BE", "\u0628\u0644\u062c\u06cc\u0645" },
            { "BG", "\u0628\u0644\u063a\u0627\u0631\u06cc\u0627" },
            { "RW", "\u0631\u0648\u0622\u0646\u062f\u0627" },
            { "JP", "\u062c\u0627\u067e\u0627\u0646" },
            { "BN", "\u0628\u0631\u0648\u0646\u06cc" },
            { "BO", "\u0628\u0648\u0644\u06cc\u0648\u06cc\u0627" },
            { "BR", "\u0628\u0631\u0627\u0632\u06cc\u0644" },
            { "BS", "\u0628\u0647\u0627\u0645\u0627\u0633" },
            { "SE", "\u0633\u0648\u06cc\u062f\u0646" },
            { "SG", "\u0633\u06cc\u0646\u06af\u0627\u067e\u0648\u0631" },
            { "SI", "\u0633\u0644\u0648\u0646\u06cc\u0627" },
            { "SK", "\u0633\u0644\u0648\u0627\u06a9\u06cc\u0627" },
            { "SL", "\u0633\u06cc\u0631\u0627\u0644\u06cc\u0648\u0646" },
            { "KE", "\u06a9\u06cc\u0646\u06cc\u0627" },
            { "SN", "\u0633\u06cc\u0646\u06cc\u06af\u0627\u0644" },
            { "KG", "\u0642\u0631\u063a\u0632\u0633\u062a\u0627\u0646" },
            { "SO", "\u0633\u0648\u0645\u0627\u0644\u06cc\u0647" },
            { "KH", "\u06a9\u0645\u067e\u0648\u0686\u06cc\u0627" },
            { "sq", "\u0627\u0644\u0628\u0627\u0646\u06cc\u0627\u06cc\u06cc" },
            { "CD", "\u06a9\u0627\u0646\u06af\u0648 - \u06a9\u06cc\u0646\u0634\u0627\u0633\u0627" },
            { "SV", "\u0627\u0644\u0633\u0644\u0648\u0627\u062f\u0648\u0631" },
            { "sv", "\u0633\u0648\u06cc\u062f\u0646\u06cc" },
            { "CG", "\u06a9\u0627\u0646\u06af\u0648 - \u0628\u0631\u0627\u0632\u0648\u06cc\u0644" },
            { "ko", "\u06a9\u0648\u0631\u06cc\u0627\u06cc\u06cc" },
            { "sw", "\u0633\u0648\u0627\u062d\u0644\u06cc" },
            { "CH", "\u0633\u0648\u06cc\u0633" },
            { "KP", "\u06a9\u0648\u0631\u06cc\u0627\u06cc \u0634\u0645\u0627\u0644\u06cc" },
            { "KR", "\u06a9\u0648\u0631\u06cc\u0627\u06cc \u062c\u0646\u0648\u0628\u06cc" },
            { "CL", "\u0686\u0644\u06cc" },
            { "CO", "\u06a9\u0648\u0644\u0645\u0628\u06cc\u0627" },
            { "ky", "\u0642\u0631\u063a\u0632\u06cc" },
            { "CR", "\u06a9\u0627\u0633\u062a\u0631\u06cc\u06a9\u0627" },
            { "CU", "\u06a9\u06cc\u0648\u0628\u0627" },
            { "tg", "\u062a\u0627\u062c\u06a9\u06cc" },
            { "TJ", "\u062a\u0627\u062c\u06a9\u0633\u062a\u0627\u0646" },
            { "LK", "\u0633\u0631\u06cc\u0644\u0627\u0646\u06a9\u0627" },
            { "DK", "\u062f\u0646\u0645\u0627\u0631\u06a9" },
            { "LS", "\u0644\u06cc\u0633\u0648\u062a\u0648" },
            { "LT", "\u0644\u062a\u0648\u0627\u0646\u06cc\u0627" },
            { "LV", "\u0644\u0627\u062a\u0648\u06cc\u0627" },
            { "UA", "\u0627\u06a9\u0631\u0627\u06cc\u0646" },
            { "LY", "\u0644\u06cc\u0628\u06cc\u0627" },
            { "UG", "\u06cc\u0648\u06af\u0627\u0646\u062f\u0627" },
            { "dv", "\u0645\u0627\u0644\u062f\u06cc\u0648\u06cc" },
            { "MG", "\u0645\u0627\u062f\u063a\u0627\u0633\u06a9\u0631" },
            { "EE", "\u0627\u0633\u062a\u0648\u0646\u06cc\u0627" },
            { "mn", metaValue_mn },
            { "MN", "\u0645\u0646\u06af\u0648\u0644\u06cc\u0627" },
            { "UY", "\u06cc\u0648\u0631\u0648\u06af\u0648\u0627\u06cc" },
            { "MR", "\u0645\u0648\u0631\u06cc\u062a\u0627\u0646\u06cc\u0627" },
            { "MT", "\u0645\u0627\u0644\u062a\u0627" },
            { "MX", "\u0645\u06a9\u0633\u06cc\u06a9\u0648" },
            { "MY", "\u0645\u0627\u0644\u06cc\u0632\u06cc\u0627" },
            { "ER", "\u0627\u0631\u06cc\u062a\u0631\u06cc\u0627" },
            { "MZ", "\u0645\u0648\u0632\u0645\u0628\u06cc\u0642" },
            { "VC", "\u0633\u0646\u062a \u0648\u06cc\u0646\u0633\u0646\u062a \u0648 \u06af\u0631\u0646\u0627\u062f\u06cc\u0646\u200c\u0647\u0627" },
            { "ES", "\u0647\u0633\u067e\u0627\u0646\u06cc\u0647" },
            { "es", "\u0647\u0633\u067e\u0627\u0646\u0648\u06cc" },
            { "ET", "\u0627\u06cc\u062a\u0648\u067e\u06cc\u0627" },
            { "VE", "\u0648\u0646\u0632\u0648\u06cc\u0644\u0627" },
            { "NE", "\u0646\u0627\u06cc\u062c\u0631" },
            { "ne", "\u0646\u06cc\u067e\u0627\u0644\u06cc" },
            { "NG", "\u0646\u06cc\u062c\u0631\u06cc\u0627" },
            { "NI", "\u0646\u06cc\u06a9\u0627\u0631\u0627\u06af\u0648\u0627" },
            { "NL", "\u0647\u0627\u0644\u0646\u062f" },
            { "nl", "\u0647\u0627\u0644\u0646\u062f\u06cc" },
            { "NO", "\u0646\u0627\u0631\u0648\u06cc" },
            { "no", "\u0646\u0627\u0631\u0648\u06cc\u0698\u06cc" },
            { "NP", "\u0646\u06cc\u067e\u0627\u0644" },
            { "FI", "\u0641\u0646\u0644\u0646\u062f" },
            { "fi", "\u0641\u0646\u0644\u0646\u062f\u06cc" },
            { "FM", "\u0645\u06cc\u06a9\u0631\u0648\u0646\u0632\u06cc\u0627" },
            { "NZ", "\u0632\u06cc\u0644\u0627\u0646\u062f \u062c\u062f\u06cc\u062f" },
            { "ga", "\u0622\u06cc\u0631\u0644\u0646\u062f\u06cc" },
            { "GD", "\u06af\u0631\u06cc\u0646\u0627\u062f\u0627" },
            { "Mong", metaValue_mn },
            { "GH", "\u06af\u0627\u0646\u0627" },
            { "GN", "\u06af\u06cc\u0646\u06cc\u0627" },
            { "GQ", "\u06af\u06cc\u0646\u06cc\u0627 \u0627\u0633\u062a\u0648\u0627\u06cc\u06cc" },
            { "GT", "\u06af\u0648\u0627\u062a\u06cc\u0645\u0627\u0644\u0627" },
            { "GW", "\u06af\u06cc\u0646\u06cc\u0627 \u0628\u06cc\u0633\u0627\u0626\u0648" },
            { "PA", "\u067e\u0627\u0646\u0627\u0645\u0647" },
            { "GY", "\u06af\u06cc\u0627\u0646\u0627" },
            { "XK", "\u06a9\u0648\u0633\u0648\u0627" },
            { "PE", "\u067e\u06cc\u0631\u0648" },
            { "PG", "\u067e\u0627\u067e\u0648\u0627 \u0646\u06cc\u0648 \u06af\u06cc\u0646\u06cc\u0627" },
            { "ckb", "\u06a9\u0631\u062f\u06cc \u0633\u0648\u0631\u0627\u0646\u06cc" },
            { "PL", "\u067e\u0648\u0644\u0646\u062f" },
            { "pl", "\u067e\u0648\u0644\u0646\u062f\u06cc" },
        };
        return data;
    }
}

==> openjdk-src-19.0.1.u10-3-armv7h.pkg.tar.xz: jdk.localedata/sun/util/resources/cldr/ext/LocaleNames_fa_AF.java <==
/*
 * Copyright (c) 2012, 2022, Oracle and/or its affiliates. All rights reserved.
 * DO NOT ALTER OR REMOVE COPYRIGHT NOTICES OR THIS FILE HEADER.
 *
 * This code is free software; you can redistribute it and/or modify it
 * under the terms of the GNU General Public License version 2 only, as
 * published by the Free Software Foundation.  Oracle designates this
 * particular file as subject to the "Classpath" exception as provided
 * by Oracle in the LICENSE file that accompanied this code.
 *
 * This code is distributed in the hope that it will be useful, but WITHOUT
 * ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
 * FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License
 * version 2 for more details (a copy is included in the LICENSE file that
 * accompanied this code).
 *
 * You should have received a copy of the GNU General Public License version
 * 2 along with this work; if not, write to the Free Software Foundation,
 * Inc., 51 Franklin St, Fifth Floor, Boston, MA 02110-1301 USA.
 *
 * Please contact Oracle, 500 Oracle Parkway, Redwood Shores, CA 94065 USA
 * or visit www.oracle.com if you need additional information or have any
 * questions.
 */

/*
 * COPYRIGHT AND PERMISSION NOTICE
 *
 * Copyright (c) 1991-2022 Unicode, Inc. All rights reserved.
 * Distributed under the Terms of Use in https://www.unicode.org/copyright.html.
 *
 * Permission is hereby granted, free of charge, to any person obtaining
 * a copy of the Unicode data files and any associated documentation
 * (the "Data Files") or Unicode software and any associated documentation
 * (the "Software") to deal in the Data Files or Software
 * without restriction, including without limitation the rights to use,
 * copy, modify, merge, publish, distribute, and/or sell copies of
 * the Data Files or Software, and to permit persons to whom the Data Files
 * or Software are furnished to do so, provided that either
 * (a) this copyright and permission notice appear with all copies
 * of the Data Files or Software, or
 * (b) this copyright and permission notice appear in associated
 * Documentation.
 *
 * THE DATA FILES AND SOFTWARE ARE PROVIDED "AS IS", WITHOUT WARRANTY OF
 * ANY KIND, EXPRESS OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE
 * WARRANTIES OF MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND
 * NONINFRINGEMENT OF THIRD PARTY RIGHTS.
 * IN NO EVENT SHALL THE COPYRIGHT HOLDER OR HOLDERS INCLUDED IN THIS
 * NOTICE BE LIABLE FOR ANY CLAIM, OR ANY SPECIAL INDIRECT OR CONSEQUENTIAL
 * DAMAGES, OR ANY DAMAGES WHATSOEVER RESULTING FROM LOSS OF USE,
 * DATA OR PROFITS, WHETHER IN AN ACTION OF CONTRACT, NEGLIGENCE OR OTHER
 * TORTIOUS ACTION, ARISING OUT OF OR IN CONNECTION WITH THE USE OR
 * PERFORMANCE OF THE DATA FILES OR SOFTWARE.
 *
 * Except as contained in this notice, the name of a copyright holder
 * shall not be used in advertising or otherwise to promote the sale,
 * use or other dealings in these Data Files or Software without prior
 * written authorization of the copyright holder.
 */

package sun.util.resources.cldr.ext;

import sun.util.resources.OpenListResourceBundle;

public class LocaleNames_fa_AF extends OpenListResourceBundle {
    @Override
    protected final Object[][] getContents() {
        final String metaValue_mn = "\u0645\u063a\u0644\u06cc";
        final Object[][] data = new Object[][] {
            { "ksh", "\u06a9\u0644\u0646\u06cc" },
            { "HK", "\u0647\u0627\u0646\u06af \u06a9\u0627\u0646\u06af\u060c \u0646\u0627\u062d\u06cc\u0647\u0654 \u0648\u06cc\u0698\u0647\u0654 \u062d\u06a9\u0648\u0645\u062a\u06cc \u0686\u06cc\u0646" },
            { "PT", "\u067e\u0631\u062a\u06af\u0627\u0644" },
            { "pt", "\u067e\u0631\u062a\u06af\u0627\u0644\u06cc" },
            { "HN", "\u0647\u0627\u0646\u062f\u0648\u0631\u0627\u0633" },
            { "PY", "\u067e\u0627\u0631\u0627\u06af\u0648\u0627\u06cc" },
            { "HR", "\u06a9\u0631\u0648\u0634\u06cc\u0627" },
            { "hr", "\u06a9\u0631\u0648\u0634\u06cc\u0627\u06cc\u06cc" },
            { "lus", "\u0645\u06cc\u0632\u0648\u06cc\u06cc" },
            { "HT", "\u0647\u0627\u06cc\u062a\u06cc" },
            { "ID", "\u0627\u0646\u062f\u0648\u0646\u06cc\u0632\u06cc\u0627" },
            { "id", "\u0627\u0646\u062f\u0648\u0646\u06cc\u0632\u06cc\u0627\u06cc\u06cc" },
            { "IE", "\u0622\u06cc\u0631\u0644\u0646\u062f" },
            { "zza", "\u0632\u0627\u0632\u0627\u06a9\u06cc" },
            { "ab", "\u0627\u0641\u0631\u06cc\u06a9\u0627\u0646\u0633" },
            { "AD", "\u0627\u0646\u062f\u0648\u0631\u0627" },
            { "nl_BE", "\u0641\u0644\u0645\u06cc\u0634" },
            { "AG", "\u0627\u0646\u062a\u06cc\u06af\u0648\u0627 \u0648 \u0628\u0627\u0631\u0628\u0648\u062f\u0627" },
            { "IS", "\u0622\u06cc\u0633\u0644\u0646\u062f" },
            { "is", "\u0622\u06cc\u0633\u0644\u0646\u062f\u06cc" },
            { "AL", "\u0627\u0644\u0628\u0627\u0646\u06cc\u0627" },
            { "it", "\u0627\u06cc\u062a\u0627\u0644\u0648\u06cc" },
            { "AO", "\u0627\u0646\u06af\u0648\u0644\u0627" },
            { "AQ", "\u0627\u0646\u062a\u0631\u06a9\u062a\u06cc\u06a9\u0627" },
            { "AR", "\u0627\u0631\u062c\u0646\u062a\u0627\u06cc\u0646" },
            { "as", "\u0627\u0633\u0627\u0645\u06cc" },
            { "ja", "\u062c\u0627\u067e\u0627\u0646\u06cc" },
            { "az", "\u0622\u0630\u0631\u0628\u0627\u06cc\u062c\u0627\u0646\u06cc" },
            { "RO", "\u0631\u0648\u0645\u0627\u0646\u06cc\u0627" },
            { "ZW", "\u0632\u06cc\u0645\u0628\u0627\u0628\u0648\u06cc" },
            { "BA", "\u0628\u0648\u0633\u0646\u06cc\u0627 \u0648 \u0647\u0631\u0632\u0647\u200c\u06af\u0648\u06cc\u0646\u0627" },
            { "BD", "\u0628\u0646\u06af\u0644\u0647\u200c\u062f\u06cc\u0634" },
            { "BE", "\u0628\u0644\u062c\u06cc\u0645" },
            { "BG", "\u0628\u0644\u063a\u0627\u0631\u06cc\u0627" },
            { "JP", "\u062c\u0627\u067e\u0627\u0646" },
            { "BN", "\u0628\u0631\u0648\u0646\u06cc" },
            { "BO", "\u0628\u0648\u0644\u06cc\u0648\u06cc\u0627" },
            { "BR", "\u0628\u0631\u0627\u0632\u06cc\u0644" },
            { "BS", "\u0628\u0647\u0627\u0645\u0627\u0633" },
            { "SE", "\u0633\u0648\u06cc\u062f\u0646" },
            { "SG", "\u0633\u06cc\u0646\u06af\u0627\u067e\u0648\u0631" },
            { "mai", "\u0645\u0627\u06cc\u062a\u06cc\u0644\u06cc" },
            { "SI", "\u0633\u0644\u0648\u0646\u06cc\u0627" },
            { "SJ", "\u0627\u0633\u0648\u0627\u0644\u0628\u0627\u0631\u062f \u0648 \u062c\u0627\u0646 \u0645\u0627\u06cc\u0646" },
            { "SK", "\u0633\u0644\u0648\u0627\u06a9\u06cc\u0627" },
            { "SL", "\u0633\u06cc\u0631\u0627\u0644\u06cc\u0648\u0646" },
            { "KE", "\u06a9\u06cc\u0646\u06cc\u0627" },
            { "SN", "\u0633\u06cc\u0646\u06cc\u06af\u0627\u0644" },
            { "SO", "\u0633\u0648\u0645\u0627\u0644\u06cc\u0647" },
            { "KH", "\u06a9\u0645\u067e\u0648\u0686\u06cc\u0627" },
            { "sq", "\u0627\u0644\u0628\u0627\u0646\u06cc\u0627\u06cc\u06cc" },
            { "CD", "\u06a9\u0627\u0646\u06af\u0648 - \u06a9\u06cc\u0646\u0634\u0627\u0633\u0627" },
            { "SV", "\u0627\u0644\u0633\u0644\u0648\u0627\u062f\u0648\u0631" },
            { "sv", "\u0633\u0648\u06cc\u062f\u0646\u06cc" },
            { "CG", "\u06a9\u0627\u0646\u06af\u0648 - \u0628\u0631\u0627\u0632\u0648\u06cc\u0644" },
            { "ko", "\u06a9\u0648\u0631\u06cc\u0627\u06cc\u06cc" },
            { "sw", "\u0633\u0648\u0627\u062d\u0644\u06cc" },
            { "CH", "\u0633\u0648\u06cc\u0633" },
            { "KP", "\u06a9\u0648\u0631\u06cc\u0627\u06cc \u0634\u0645\u0627\u0644\u06cc" },
            { "KR", "\u06a9\u0648\u0631\u06cc\u0627\u06cc \u062c\u0646\u0648\u0628\u06cc" },
            { "CL", "\u0686\u0644\u06cc" },
            { "CO", "\u06a9\u0648\u0644\u0645\u0628\u06cc\u0627" },
            { "ky", "\u0642\u0631\u063a\u0632\u06cc" },
            { "CR", "\u06a9\u0627\u0633\u062a\u0631\u06cc\u06a9\u0627" },
            { "CU", "\u06a9\u06cc\u0648\u0628\u0627" },
            { "tg", "\u062a\u0627\u062c\u06a9\u06cc" },
            { "TJ", "\u062a\u0627\u062c\u06a9\u0633\u062a\u0627\u0646" },
            { "LK", "\u0633\u0631\u06cc\u0644\u0627\u0646\u06a9\u0627" },
            { "zh_Hans", "\u0686\u06cc\u0646\u06cc \u0633\u0627\u062f\u0647 \u0634\u062f\u0647" },
            { "ast", "\u0627\u062a\u0631\u06cc\u0634\u06cc" },
            { "DK", "\u062f\u0646\u0645\u0627\u0631\u06a9" },
            { "LS", "\u0644\u06cc\u0633\u0648\u062a\u0648" },
            { "LT", "\u0644\u062a\u0648\u0627\u0646\u06cc\u0627" },
            { "LV", "\u0644\u0627\u062a\u0648\u06cc\u0627" },
            { "LY", "\u0644\u06cc\u0628\u06cc\u0627" },
            { "UG", "\u06cc\u0648\u06af\u0627\u0646\u062f\u0627" },
            { "dv", "\u0645\u0627\u0644\u062f\u06cc\u0648\u06cc" },
            { "MG", "\u0645\u0627\u062f\u063a\u0627\u0633\u06a9\u0631" },
            { "EA", "\u0633\u0626\u0648\u062a\u0627 \u0648 \u0645\u0644\u06cc\u0644\u0627" },
            { "EE", "\u0627\u0633\u062a\u0648\u0646\u06cc\u0627" },
            { "mn", metaValue_mn },
            { "MN", "\u0645\u0646\u06af\u0648\u0644\u06cc\u0627" },
            { "UY", "\u06cc\u0648\u0631\u0648\u06af\u0648\u0627\u06cc" },
            { "MR", "\u0645\u0648\u0631\u06cc\u062a\u0627\u0646\u06cc\u0627" },
            { "MT", "\u0645\u0627\u0644\u062a\u0627" },
            { "MX", "\u0645\u06a9\u0633\u06cc\u06a9\u0648" },
            { "MY", "\u0645\u0627\u0644\u06cc\u0632\u06cc\u0627" },
            { "ER", "\u0627\u0631\u06cc\u062a\u0631\u06cc\u0627" },
            { "MZ", "\u0645\u0648\u0632\u0645\u0628\u06cc\u0642" },
            { "VC", "\u0633\u0646\u062a \u0648\u06cc\u0646\u0633\u0646\u062a \u0648 \u06af\u0631\u0646\u0627\u062f\u06cc\u0646\u200c\u0647\u0627" },
            { "ES", "\u0647\u0633\u067e\u0627\u0646\u06cc\u0647" },
            { "es", "\u0647\u0633\u067e\u0627\u0646\u0648\u06cc" },
            { "ET", "\u0627\u06cc\u062a\u0648\u067e\u06cc\u0627" },
            { "VE", "\u0648\u0646\u0632\u0648\u06cc\u0644\u0627" },
            { "nb", "\u0646\u0631\u0648\u0698\u06cc \u06a9\u062a\u0627\u0628\u06cc" },
            { "ne", "\u0646\u06cc\u067e\u0627\u0644\u06cc" },
            { "NG", "\u0646\u06cc\u062c\u0631\u06cc\u0627" },
            { "NI", "\u0646\u06cc\u06a9\u0627\u0631\u0627\u06af\u0648\u0627" },
            { "NL", "\u0647\u0627\u0644\u0646\u062f" },
            { "nl", "\u0647\u0627\u0644\u0646\u062f\u06cc" },
            { "nn", "\u0646\u0631\u0648\u0698\u06cc \u0646\u0648" },
            { "NO", "\u0646\u0627\u0631\u0648\u06cc" },
            { "no", "\u0646\u0627\u0631\u0648\u06cc\u0698\u06cc" },
            { "NP", "\u0646\u06cc\u067e\u0627\u0644" },
            { "FI", "\u0641\u0646\u0644\u0646\u062f" },
            { "fi", "\u0641\u0646\u0644\u0646\u062f\u06cc" },
            { "FM", "\u0645\u06cc\u06a9\u0631\u0648\u0646\u0632\u06cc\u0627" },
            { "NZ", "\u0632\u06cc\u0644\u0627\u0646\u062f \u062c\u062f\u06cc\u062f" },
            { "ga", "\u0622\u06cc\u0631\u0644\u0646\u062f\u06cc" },
            { "ar_001", "\u0639\u0631\u0628\u06cc \u0641\u0635\u06cc\u062d" },
            { "GD", "\u06af\u0631\u06cc\u0646\u0627\u062f\u0627" },
            { "Mong", metaValue_mn },
            { "GH", "\u06af\u0627\u0646\u0627" },
            { "GN", "\u06af\u06cc\u0646\u06cc\u0627" },
            { "GQ", "\u06af\u06cc\u0646\u06cc\u0627 \u0627\u0633\u062a\u0648\u0627\u06cc\u06cc" },
            { "GT", "\u06af\u0648\u0627\u062a\u06cc\u0645\u0627\u0644\u0627" },
            { "srn", "\u0632\u0628\u0627\u0646 \u0633\u0631\u0627\u0646\u0627\u0646" },
            { "GW", "\u06af\u06cc\u0646\u06cc\u0627 \u0628\u06cc\u0633\u0627\u0626\u0648" },
            { "PA", "\u067e\u0627\u0646\u0627\u0645\u0647" },
            { "GY", "\u06af\u06cc\u0627\u0646\u0627" },
            { "XK", "\u06a9\u0648\u0633\u0648\u0627" },
            { "PE", "\u067e\u06cc\u0631\u0648" },
            { "PG", "\u067e\u0627\u067e\u0648\u0627 \u0646\u06cc\u0648 \u06af\u06cc\u0646\u06cc\u0627" },
            { "ckb", "\u06a9\u0631\u062f\u06cc \u0633\u0648\u0631\u0627\u0646\u06cc" },
            { "PL", "\u067e\u0648\u0644\u0646\u062f" },
            { "pl", "\u067e\u0648\u0644\u0646\u062f\u06cc" },
        };
        return data;
    }
}
